@@ -670,10 +670,10 @@ get_window_rect (WnckWindow         *window,
   
   x += wnck_workspace_get_viewport_x (workspace);
   y += wnck_workspace_get_viewport_y (workspace);
-  x *= width_ratio;
-  y *= height_ratio;
-  width *= width_ratio;
-  height *= height_ratio;
+  x = x * width_ratio + 0.5;
+  y = y * height_ratio + 0.5;
+  width = width * width_ratio + 0.5;
+  height = height * height_ratio + 0.5;
   
   x += workspace_rect->x;
   y += workspace_rect->y;
@@ -1247,24 +1247,38 @@ wnck_pager_drag_motion (GtkWidget          *widget,
                         guint               time)
 {
   WnckPager *pager;
+  gint previous_workspace;
 
   pager = WNCK_PAGER (widget);
 
+  previous_workspace = pager->priv->prelight;
+  wnck_pager_check_prelight (pager, x, y, TRUE);
+
   if (gtk_drag_dest_find_target (widget, context, NULL))
     {
       gdk_drag_status (context, context->suggested_action, time);
     }
   else 
     {
-      if (pager->priv->dnd_activate == 0)   
-         pager->priv->dnd_activate = g_timeout_add (WNCK_ACTIVATE_TIMEOUT,
-                                                    wnck_pager_drag_motion_timeout,
-                                                    pager);
-
-      pager->priv->dnd_time = time;
       gdk_drag_status (context, 0, time);
+
+      if (pager->priv->prelight != previous_workspace &&
+	  pager->priv->dnd_activate != 0)
+	{
+	  /* remove timeout, the window we hover over changed */
+	  g_source_remove (pager->priv->dnd_activate);
+	  pager->priv->dnd_activate = 0;
+	  pager->priv->dnd_time = 0;
+	}
+
+      if (pager->priv->dnd_activate == 0 && pager->priv->prelight > -1)   
+	{
+	  pager->priv->dnd_activate = g_timeout_add (WNCK_ACTIVATE_TIMEOUT,
+                                                     wnck_pager_drag_motion_timeout,
+                                                     pager);
+	  pager->priv->dnd_time = time;
+	}
     }    
-  wnck_pager_check_prelight (pager, x, y, TRUE);
 
   return (pager->priv->prelight != -1);
 }
