@@ -1622,22 +1622,22 @@ _wnck_gdk_pixbuf_get_from_pixmap (GdkPixbuf   *dest,
 
   if (drawable)
     {
-      cmap = get_cmap (drawable);
+			cmap = get_cmap (drawable);
 
-      /* GDK is supposed to do this but doesn't in GTK 2.0.2,
-       * fixed in 2.0.3
-       */
-      if (width < 0)
-        gdk_drawable_get_size (drawable, &width, NULL);
-      if (height < 0)
-        gdk_drawable_get_size (drawable, NULL, &height);
-
-      retval = gdk_pixbuf_get_from_drawable (dest,
-                                             drawable,
-                                             cmap,
-                                             src_x, src_y,
-                                             dest_x, dest_y,
-                                             width, height);
+			/* GDK is supposed to do this but doesn't in GTK 2.0.2,
+			 * fixed in 2.0.3
+			 */
+			if (width < 0)
+				gdk_drawable_get_size (drawable, &width, NULL);
+			if (height < 0)
+				gdk_drawable_get_size (drawable, NULL, &height);
+			
+			retval = gdk_pixbuf_get_from_drawable (dest,
+																						 drawable,
+																						 cmap,
+																						 src_x, src_y,
+																						 dest_x, dest_y,
+																						 width, height);
     }
 
   if (cmap)
@@ -2237,6 +2237,36 @@ _wnck_get_window_geometry (Screen *screen,
     *heightp = height;
 }
 
+void _wnck_set_window_geometry (Screen *screen,
+                                Window  xwindow,
+                                int     gravity_and_flags,
+                                int     x,
+                                int     y,
+                                int     width,
+                                int     height)
+{
+  XEvent xev;
+
+  xev.xclient.type = ClientMessage;
+  xev.xclient.serial = 0;
+  xev.xclient.send_event = True;
+  xev.xclient.display = gdk_display;
+  xev.xclient.window = xwindow;
+  xev.xclient.message_type = _wnck_atom_get ("_NET_MOVERESIZE_WINDOW");
+  xev.xclient.format = 32;
+  xev.xclient.data.l[0] = gravity_and_flags;
+  xev.xclient.data.l[1] = x;
+  xev.xclient.data.l[2] = y;
+  xev.xclient.data.l[3] = width;
+  xev.xclient.data.l[4] = height;
+
+  XSendEvent (gdk_display,
+              RootWindowOfScreen (screen),
+              False,
+              SubstructureRedirectMask | SubstructureNotifyMask,
+              &xev);
+}
+
 void
 _wnck_get_window_position (Screen *screen,
 			   Window  xwindow,
